==> haskell-fgl-5.5.2.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fgl
version: 5.5.2.3
id: fgl-5.5.2.3-2lpbGiGoHEs1407lKEeQZu
key: fgl-5.5.2.3-2lpbGiGoHEs1407lKEeQZu
license: BSD3
maintainer: Ivan.Miljenovic@gmail.com
synopsis: Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.
    .
    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.
category: Data Structures, Graphs
author: Martin Erwig, Ivan Lazar Miljenovic
exposed: True
exposed-modules:
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Monad Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Tree Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
hidden-modules: Paths_fgl
abi: b015c21d56380e7992f4236e168e9739
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fgl-5.5.2.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/fgl-5.5.2.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/fgl-5.5.2.3
hs-libraries: HSfgl-5.5.2.3-2lpbGiGoHEs1407lKEeQZu
depends:
    array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html: /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-5.5.3.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fgl
version: 5.5.3.0
id: fgl-5.5.3.0-KO9F4uETTjy3vgLQ22ev7I
key: fgl-5.5.3.0-KO9F4uETTjy3vgLQ22ev7I
license: BSD3
maintainer: Ivan.Miljenovic@gmail.com
synopsis: Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.
    .
    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.
category: Data Structures, Graphs
author: Martin Erwig, Ivan Lazar Miljenovic
exposed: True
exposed-modules:
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Monad Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Tree Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
hidden-modules: Paths_fgl
abi: 3cd27e7f1f292d726849272ddd0991f2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fgl-5.5.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/fgl-5.5.3.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/fgl-5.5.3.0
hs-libraries: HSfgl-5.5.3.0-KO9F4uETTjy3vgLQ22ev7I
depends:
    array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html: /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
